@@ -1,5 +1,5 @@
 package Net::Stomp::Producer;
-$Net::Stomp::Producer::VERSION = '2.003';
+$Net::Stomp::Producer::VERSION = '2.004';
 {
   $Net::Stomp::Producer::DIST = 'Net-Stomp-Producer';
 }
@@ -124,7 +124,11 @@ sub _really_send {
     my $method = $self->_send_method_to_call;
 
     $self->reconnect_on_failure(
-        sub { $_[0]->connection->$method($_[1]) },
+        sub {
+            my $ret = $_[0]->connection->$method($_[1]);
+            die "Call to $method failed"
+                unless $ret;
+        },
         $frame,
     );
 }
@@ -240,7 +244,7 @@ Net::Stomp::Producer - helper object to send messages via Net::Stomp
 
 =head1 VERSION
 
-version 2.003
+version 2.004
 
 =head1 SYNOPSIS
 
